Index: tests/src/Makefile.am
===================================================================
--- tests/src/Makefile.am	(revision bf1c67467bcd62d222f41e63adcf8e3771a09a03)
+++ tests/src/Makefile.am	(revision ca1abdd5271f95cfc6949637f31d9347358b246e)
@@ -27,5 +27,5 @@
 	test-pitchfcomb \
 	test-pitchmcomb \
-	test-pitchdetection \
+	test-pitch \
 	test-beattracking \
 	test-onset \
Index: tests/src/test-pitchdetection.c
===================================================================
--- tests/src/test-pitchdetection.c	(revision bf1c67467bcd62d222f41e63adcf8e3771a09a03)
+++ tests/src/test-pitchdetection.c	(revision ca1abdd5271f95cfc6949637f31d9347358b246e)
@@ -11,14 +11,14 @@
   fvec_t *in = new_fvec (hop_s, channels);      /* input buffer */
   fvec_t *out = new_fvec (1, channels); /* input buffer */
-  aubio_pitchdetection_t *o =
-      new_aubio_pitchdetection ("default", win_s, hop_s, channels, samplerate);
+  aubio_pitch_t *o =
+      new_aubio_pitch ("default", win_s, hop_s, channels, samplerate);
   uint_t i = 0;
 
   while (i < 100) {
-    aubio_pitchdetection_do (o, in, out);
+    aubio_pitch_do (o, in, out);
     i++;
   };
 
-  del_aubio_pitchdetection (o);
+  del_aubio_pitch (o);
   del_fvec (in);
   aubio_cleanup ();

Index: tests/python/src/pitch/pitchdetection.py
===================================================================
--- tests/python/src/pitch/pitchdetection.py	(revision bf1c67467bcd62d222f41e63adcf8e3771a09a03)
+++ tests/python/src/pitch/pitchdetection.py	(revision ca1abdd5271f95cfc6949637f31d9347358b246e)
@@ -7,5 +7,5 @@
 samplerate = 44100.
 
-class pitchdetection_test_case(unittest.TestCase):
+class pitch_test_case(unittest.TestCase):
 
   def setUp(self, type = aubio_pitch_yinfft, mode = aubio_pitchm_freq):
@@ -15,25 +15,25 @@
       mode = aubio_pitchm_freq):
     self.type = type
-    self.o = new_aubio_pitchdetection(buf_size, hop_size,
+    self.o = new_aubio_pitch(buf_size, hop_size,
         channels, int(samplerate), type, mode)
 
   def tearDown(self):
-    del_aubio_pitchdetection(self.o)
+    del_aubio_pitch(self.o)
 
-  def test_pitchdetection(self):
-    """ create and delete pitchdetection """
+  def test_pitch(self):
+    """ create and delete pitch """
     pass
 
-  def test_pitchdetection_run_zeroes(self):
-    """ run pitchdetection on an empty buffer """
+  def test_pitch_run_zeroes(self):
+    """ run pitch on an empty buffer """
     vec = new_fvec(buf_size, channels)
     out = new_fvec(1, channels)
     for i in range(100):
-      aubio_pitchdetection_do(self.o,vec, out)
+      aubio_pitch_do(self.o,vec, out)
       self.assertEqual(fvec_read_sample(out, 0, 0),0.)
     del vec
 
-  def test_pitchdetection_run_4_impulses(self):
-    """ run pitchdetection on a train of 4 impulses """
+  def test_pitch_run_4_impulses(self):
+    """ run pitch on a train of 4 impulses """
     vec = new_fvec(buf_size, channels)
     out = new_fvec(1, channels)
@@ -44,10 +44,10 @@
     frequency = samplerate/2*4/buf_size
     for i in range(100):
-      aubio_pitchdetection_do(self.o,vec, out)
+      aubio_pitch_do(self.o,vec, out)
       self.assertEqual(fvec_read_sample(out, 0, 0),frequency)
     del vec
 
-  def test_pitchdetection_run_4_positive_impulses(self):
-    """ run pitchdetection on a train of 4 positive impulses of arbitrary size """
+  def test_pitch_run_4_positive_impulses(self):
+    """ run pitch on a train of 4 positive impulses of arbitrary size """
     vec = new_fvec(buf_size, channels)
     out = new_fvec(1, channels)
@@ -58,10 +58,10 @@
       fvec_write_sample(vec, 2.-.01*i,0,  buf_size/2)
       fvec_write_sample(vec, 2.-.01*i,0,3*buf_size/4)
-      aubio_pitchdetection_do(self.o,vec, out)
+      aubio_pitch_do(self.o,vec, out)
       self.assertAlmostEqual(fvec_read_sample(out, 0, 0),frequency,1)
     del vec
 
-  def test_pitchdetection_run_4_negative_impulses(self):
-    """ run pitchdetection on a train of 4 negative impulses of arbitrary size """
+  def test_pitch_run_4_negative_impulses(self):
+    """ run pitch on a train of 4 negative impulses of arbitrary size """
     vec = new_fvec(buf_size, channels)
     out = new_fvec(1, channels)
@@ -72,10 +72,10 @@
       fvec_write_sample(vec,-.01*i,0,  buf_size/2)
       fvec_write_sample(vec,-.01*i,0,3*buf_size/4)
-      aubio_pitchdetection_do(self.o,vec, out)
+      aubio_pitch_do(self.o,vec, out)
       self.assertAlmostEqual(fvec_read_sample(out, 0, 0),frequency,1)
     del vec
 
-  def test_pitchdetection_run_8_impulses(self):
-    """ run pitchdetection on a train of 8 impulses """
+  def test_pitch_run_8_impulses(self):
+    """ run pitch on a train of 8 impulses """
     vec = new_fvec(buf_size, channels)
     out = new_fvec(1, channels)
@@ -89,5 +89,5 @@
     fvec_write_sample(vec,-1.,0,7*buf_size/8)
     for i in range(100):
-      aubio_pitchdetection_do(self.o,vec, out)
+      aubio_pitch_do(self.o,vec, out)
       self.assertAlmostEqual(fvec_read_sample(out, 0, 0),
         samplerate/2/buf_size*8, 1) 
@@ -95,17 +95,17 @@
 
 """
-class pitchdetection_yin_test_case(pitchdetection_test_case):
+class pitch_yin_test_case(pitchdetection_test_case):
   def setUp(self, type = aubio_pitch_yin):
     self.create(type=type)
 
-class pitchdetection_fcomb_test_case(pitchdetection_test_case):
+class pitch_fcomb_test_case(pitchdetection_test_case):
   def setUp(self, type = aubio_pitch_fcomb):
     self.create(type=type)
 
-class pitchdetection_mcomb_test_case(pitchdetection_test_case):
+class pitch_mcomb_test_case(pitchdetection_test_case):
   def setUp(self, type = aubio_pitch_mcomb):
     self.create(type=type)
 
-class pitchdetection_schmitt_test_case(pitchdetection_test_case):
+class pitch_schmitt_test_case(pitchdetection_test_case):
   def setUp(self, type = aubio_pitch_schmitt):
     self.create(type=type)